@@ -159,7 +159,7 @@ class Microservices(BaseClass, ABC):
             self.logs.warn('No se encuentra activado la validacion por redis')
         else:
             port = os.environ.get('REDIS_PORT', 6379)
-            self.redisclient = redis.StrictRedis(
+            self.redisclient = redis.Redis(
                 host=os.environ.get('REDISVALIDATE'), port=int(port), db=0)
             self.logs.info('Se encuentra activado la validacion por redis')
 
